function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _inheritsLoose(subClass, superClass) { subClass.prototype.__proto__ = superClass && superClass.prototype; subClass.__proto__ = superClass; }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

import React from 'react';
import PropTypes from 'prop-types';
import Avatar from "../Avatar";
import Icon from "../Icon";
import ListItem from "../ListItem";
import ListItemSection from "../ListItemSection";
import _ from 'lodash';
/**
 * @category containers
 * @component list-item
 * @variations collab-ui-react
 */

var SpaceListItem =
/*#__PURE__*/
function (_React$PureComponent) {
  function SpaceListItem() {
    var _temp, _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return (_temp = _this = _React$PureComponent.call.apply(_React$PureComponent, [this].concat(args)) || this, _this.state = {
      id: _.uniqueId(_this.props.id && _this.props.id + "-" || 'cui-space-list-item-')
    }, _temp) || _assertThisInitialized(_this);
  }

  var _proto = SpaceListItem.prototype;

  _proto.render = function render() {
    var _this$props = this.props,
        className = _this$props.className,
        childrenLeft = _this$props.childrenLeft,
        childrenRight = _this$props.childrenRight,
        header = _this$props.header,
        subheader = _this$props.subheader,
        isBold = _this$props.isBold,
        isAlertOn = _this$props.isAlertOn,
        isOverview = _this$props.isOverview,
        isMentioned = _this$props.isMentioned,
        isMuted = _this$props.isMuted,
        isUnread = _this$props.isUnread,
        props = _objectWithoutProperties(_this$props, ["className", "childrenLeft", "childrenRight", "header", "subheader", "isBold", "isAlertOn", "isOverview", "isMentioned", "isMuted", "isUnread"]);

    var id = this.state.id;

    var getIcon = function getIcon() {
      if (isMuted) {
        return React.createElement(Icon, {
          color: "$white-60",
          name: "alert-muted_12"
        });
      } else if (isUnread) {
        return React.createElement("i", {
          style: {
            fontSize: '12px',
            color: '#07C1E4'
          },
          className: "icon icon-unread-badge_16"
        });
      } else if (isMentioned) {
        return React.createElement(Icon, {
          color: "blue",
          name: "mention_12"
        });
      } else if (isAlertOn) {
        return React.createElement(Icon, {
          color: "$white-60",
          name: "alert_12"
        });
      }

      return null;
    };

    var leftSection = isOverview ? React.createElement(Avatar, {
      isOverview: true,
      icon: React.createElement(Icon, {
        name: "handset_24"
      })
    }) : childrenLeft;
    var rightSection = childrenRight ? childrenRight : getIcon();
    var children = [React.createElement(ListItemSection, {
      key: "child-0",
      position: "left"
    }, leftSection || React.createElement(Avatar, {
      title: "NA"
    })), React.createElement(ListItemSection, {
      key: "child-1",
      position: "center"
    }, React.createElement("div", {
      className: 'cui-list-item__header' + ("" + (isOverview && " cui-list-item__header--overview" || ''))
    }, header), React.createElement("div", {
      className: "cui-list-item__subheader"
    }, subheader)), React.createElement(ListItemSection, {
      key: "child-2",
      position: "right"
    }, rightSection)];
    return React.createElement(ListItem, _extends({
      className: "" + (isBold && " cui-list-item--unread" || '') + ("" + (className && " " + className || '')),
      id: id,
      type: "space"
    }, props), children);
  };

  _inheritsLoose(SpaceListItem, _React$PureComponent);

  return SpaceListItem;
}(React.PureComponent);

SpaceListItem.displayName = 'SpaceListItem';
export { SpaceListItem as default };
SpaceListItem.defaultProps = {
  className: '',
  childrenLeft: null,
  childrenRight: null,
  id: '',
  isBold: false,
  isAlertOn: false,
  isMentioned: false,
  isMuted: false,
  isUnread: false,
  isOverview: false,
  subheader: ''
};
SpaceListItem.propTypes = {
  /** HTML Class for associated input */
  className: PropTypes.string,

  /** Children for left section */
  childrenLeft: PropTypes.node,

  /** Children for left section */
  childrenRight: PropTypes.node,

  /** HTML ID for associated input */
  id: PropTypes.string,

  /** SpaceListItem Boolean */
  isBold: PropTypes.bool,

  /** SpaceListItem Boolean */
  isOverview: PropTypes.bool,

  /** SpaceListItem Boolean */
  isUnread: PropTypes.bool,

  /** SpaceListItem Boolean */
  isMentioned: PropTypes.bool,

  /** SpaceListItem Boolean */
  isMuted: PropTypes.bool,

  /** SpaceListItem Boolean */
  isAlertOn: PropTypes.bool,

  /** ListItem header */
  header: PropTypes.node.isRequired,

  /** ListItem header */
  subheader: PropTypes.node
};
/**
* @name Space List
*
* @category containers
* @component list-item
* @section space
*
* @js
*
import { List, SpaceListItem } from '@collab-ui/react';
import { NavLink } from 'react-router-dom';

export default class SpaceListExamples extends React.PureComponent {

  render() {
    const anchorNode = <NavLink to='/containers/list-item' />;
    return(
      <div className="medium-4 columns cui--dark">
        <List style={{backgroundColor: 'rgba(40,40,40,0.72)'}}>
          <SpaceListItem header='Header' subheader='must be very long long long long long message message' isBold/>
          <SpaceListItem header='Header' subheader='must be very long long long long long message message' isUnread/>
          <SpaceListItem header='isMentioned' isMentioned/>
          <SpaceListItem header='isMuted' isMuted/>
          <SpaceListItem header='isAlertOn' isAlertOn/>
          <SpaceListItem header='iconsPrioritized' isMuted isAlertOn isMentioned isUnread/>
          <SpaceListItem header='Header' subheader='subheader' disabled/>
          <SpaceListItem header='Header' subheader='subheader' customRefProp='innerRef' customAnchorNode={anchorNode}/>
          <SpaceListItem header='SingleRead' />
          <SpaceListItem isOverview header='Summary List Item' />
        </List>
      </div>
    );
  }
}
**/