"use strict";

exports.__esModule = true;
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _DeviceListCall = _interopRequireDefault(require("./DeviceListCall"));

var _ = require("./..");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * @category communication
 * @component alert-call
 * @variations collab-ui-react
 */
var AlertCall = function AlertCall(props) {
  var avatar = props.avatar,
      caller = props.caller,
      deviceListHeader = props.deviceListHeader,
      devices = props.devices,
      onAnswerVideo = props.onAnswerVideo,
      onAnswerVoice = props.onAnswerVoice,
      onReject = props.onReject,
      show = props.show,
      title = props.title;

  var getAvatar = function getAvatar() {
    if (avatar) {
      return avatar;
    } else {
      switch (caller.type) {
        case 'number':
          return _react.default.createElement(_.Avatar, {
            title: "#",
            alt: caller.title,
            size: "xlarge"
          });

        case 'device':
          return _react.default.createElement(_.Avatar, {
            icon: _react.default.createElement(_.Icon, {
              name: "spark-board_32"
            }),
            alt: caller.title,
            size: "xlarge"
          });

        default:
          return _react.default.createElement(_.Avatar, {
            title: caller.title,
            alt: caller.title,
            size: "xlarge"
          });
      }
    }
  };

  var getDeviceList = function getDeviceList() {
    return devices.length > 0 && _react.default.createElement(_DeviceListCall.default, {
      devices: devices,
      header: deviceListHeader
    });
  };

  return show && _react.default.createElement(_.AlertContainer, {
    className: "cui-alert--call"
  }, _react.default.createElement("div", {
    className: "cui-alert__title"
  }, title), _react.default.createElement("div", {
    className: "cui-alert__caller"
  }, getAvatar(), _react.default.createElement("div", {
    className: "cui-alert__caller-title"
  }, caller.title), _react.default.createElement("div", {
    className: "cui-alert__caller-subtitle"
  }, caller.alt)), getDeviceList(), _react.default.createElement("div", {
    className: "cui-alert--call--buttons"
  }, _react.default.createElement(_.Button, {
    children: _react.default.createElement(_.Icon, {
      name: "camera_24"
    }),
    onClick: onAnswerVideo,
    ariaLabel: "answer call with voice and video",
    color: "green",
    circle: true,
    large: true
  }), onAnswerVoice && _react.default.createElement(_.Button, {
    children: _react.default.createElement(_.Icon, {
      name: "handset_24"
    }),
    onClick: onAnswerVoice,
    ariaLabel: "answer call with voice only",
    color: "green",
    circle: true,
    large: true
  }), _react.default.createElement(_.Button, {
    children: _react.default.createElement(_.Icon, {
      name: "cancel_24"
    }),
    onClick: onReject,
    ariaLabel: "reject call",
    color: "red",
    circle: true,
    large: true
  })));
};

AlertCall.defaultProps = {
  avatar: null,
  caller: null,
  title: '',
  onRejectCall: null,
  onVoiceCall: null,
  onVideoCall: null,
  deviceListHeader: 'Device selection',
  devices: []
};
AlertCall.propTypes = {
  /**
   * required caller object
   */
  caller: _propTypes.default.shape({
    title: _propTypes.default.string.isRequired,
    alt: _propTypes.default.string,
    src: _propTypes.default.string,
    type: _propTypes.default.oneOf(['', 'number', 'device'])
  }).isRequired,

  /**
   * callback function invoked when the reject button is clicked.
   */
  onRejectCall: _propTypes.default.func,

  /**
   * callback function invoked when the handset button is clicked.
   */
  onAnswerVoice: _propTypes.default.func,

  /**
   * callback function invoked when the video button is clicked.
   */
  onAnswerVideo: _propTypes.default.func,

  /**
   * required show/hide AlertCall.
   */
  show: _propTypes.default.bool.isRequired,

  /**
   * optional title of AlertCall
   */
  title: _propTypes.default.string,

  /**
   * optional header string for device selection list
   */
  deviceListHeader: _propTypes.default.string,

  /**
   * optional list of devices to answer call with.
   */
  devices: _propTypes.default.array,

  /**
   * optional avatar prop
   */
  avatar: _propTypes.default.node
};
AlertCall.displayName = 'AlertCall';
var _default = AlertCall;
/**
* @name Call
* @description Control the avatar type by passing in the type of caller to the caller.type prop.
*
* @category communication
* @component alert
* @section call
*
* @js

import {
  Button,
  AlertCall
} from '@collab-ui/react';

export default class Default extends React.PureComponent {
  state = {
    showAlert: false,
    caller: {title: 'Jefe Guadelupe', alt: '+ 1 972-555-1212'}
  }

  render() {
    return (
      <section>
        <div>
          <div className='row'>
            <Button
              ariaLabel='Click to Open'
              onClick={() => this.setState({ showAlert: true, caller: {title: 'Jefe Guadelupe', alt: '+ 1 972-555-1212'} })}
              children='Person Caller'
              color='primary'
              size='large'
            />
          </div>
          <div className='row'>
            <br />
            <Button
              ariaLabel='Click to Open'
              onClick={() => this.setState({
                showAlert: true,
                caller: {title: 'SJC21-Babelfish', alt: '+ 1 408-555-1212', type: 'device'},
                devices: []
              })}
              children='Device Caller'
              color='primary'
              size='large'
            />
          </div>
          <div className='row'>
            <br />
            <Button
              ariaLabel='Click to Open'
              onClick={() => this.setState({
                showAlert: true,
                caller: {title: '+ 1 408-555-1212', type: 'number'},
                devices: []
              })}
              children='Number Only Caller'
              color='primary'
              size='large'
            />
          </div>
          <div className='row'>
            <br />
            <Button
              ariaLabel='Click to Open'
              onClick={() => this.setState({
                showAlert: true,
                caller: {title: '+ 1 408-555-1212', type: 'number'},
                devices: [
                  {name: 'SJC21-Babelfish', value: '1010101', type: 'device'},
                  {name: 'Use my computer', value: '2020202'}
                ] })}
              children='Caller with Device List'
              color='primary'
              size='large'
            />
          </div>
          <br />
          <AlertCall
            title='Incoming call'
            caller={this.state.caller}
            devices={this.state.devices}
            show={this.state.showAlert}
            onReject={() => this.setState({ showAlert: false})}
            onAnswerVoice={() => this.setState({ showAlert: false})}
            onAnswerVideo={() => this.setState({ showAlert: false})}
          />
        </div>
      </section>
    );
  }
}

**/

exports.default = _default;