"use strict";

exports.__esModule = true;
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _ = require("./..");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * @category communication
 * @component meeting-alert
 * @variations collab-ui-react
 */
var AlertMeeting = function AlertMeeting(props) {
  var avatar = props.avatar,
      attendees = props.attendees,
      show = props.show,
      onHide = props.onHide,
      onSnooze = props.onSnooze,
      title = props.title,
      message = props.message,
      status = props.status;

  var renderAvatar = function renderAvatar() {
    if (avatar) {
      return avatar;
    } else {
      if (attendees.length >= 2) {
        return _react.default.createElement(_.CompositeAvatar, null, _react.default.createElement(_.Avatar, {
          title: attendees[0].title,
          alt: attendees[0].alt,
          src: attendees[0].src
        }), _react.default.createElement(_.Avatar, {
          title: attendees[1].title,
          alt: attendees[1].alt,
          src: attendees[1].src
        }));
      } else if (attendees.length === 1) {
        return _react.default.createElement(_.Avatar, {
          title: attendees[0].title,
          alt: attendees[0].alt,
          src: attendees[0].src
        });
      } else {
        throw new Error('MeetingAlert needs at least one attendee to render an avatar.');
      }
    }
  };

  return show && _react.default.createElement(_.AlertContainer, {
    className: "cui-alert--meeting"
  }, renderAvatar(), _react.default.createElement("div", {
    className: 'cui-alert__content'
  }, _react.default.createElement("div", {
    className: "cui-alert__title",
    title: title
  }, title), _react.default.createElement("div", {
    className: "cui-alert__status"
  }, status), _react.default.createElement("div", {
    className: "cui-alert__message",
    title: message
  }, message)), _react.default.createElement("div", {
    className: "cui-alert__button"
  }, _react.default.createElement(_.Button, {
    children: _react.default.createElement(_.Icon, {
      name: "alarm_16"
    }),
    onClick: onSnooze,
    ariaLabel: "snooze",
    circle: true,
    large: true
  })), _react.default.createElement("div", {
    className: "cui-alert__button"
  }, _react.default.createElement(_.Button, {
    children: _react.default.createElement(_.Icon, {
      name: "cancel_16"
    }),
    onClick: onHide,
    ariaLabel: "close",
    circle: true,
    large: true
  })));
};

AlertMeeting.defaultProps = {
  attendees: [],
  title: '',
  status: '',
  message: '',
  onHide: null,
  onSnooze: null,
  avatar: null
};
AlertMeeting.propTypes = {
  /**
   * optional attendee array.  If more than one attendee, a Composite Avatar will be composed.
   * Only use first two attendees in array will be used, the others will be ignored.
   */
  attendees: _propTypes.default.arrayOf(_propTypes.default.shape({
    title: _propTypes.default.string.isRequired,
    alt: _propTypes.default.string,
    src: _propTypes.default.string
  })),

  /**
   * optional AlertMeeting Title
   */
  title: _propTypes.default.string,

  /**
   * optional AlertMeeting Status
   */
  status: _propTypes.default.string,

  /**
   * optional AlertMeeting Message
   */
  message: _propTypes.default.string,

  /**
   * show/hide AlertMeeting.
   */
  show: _propTypes.default.bool.isRequired,

  /**
   * callback function invoked on close of the Alert. Alert can be closed on click of cross button or esc key.
   * onHide is mandatory props, if not passed Alert can not be closed.
   */
  onHide: _propTypes.default.func,

  /**
   * callback function invoked when the snooze button is clicked.
   */
  onSnooze: _propTypes.default.func,

  /**
   * optional avatar prop
   */
  avatar: _propTypes.default.node
};
AlertMeeting.displayName = 'AlertMeeting';
var _default = AlertMeeting;
/**
* @name Meeting
* @description Control the avatar type by passing in an array of user data in the attendees prop.
*
* @category communication
* @component alert
* @section meeting
*
* @js

import {
  Button,
  AlertMeeting
} from '@collab-ui/react';

export default class Default extends React.PureComponent {
  state = {
    showAlert: false,
    attendees: []
  }

  render() {
    return (
      <section>
        <div>
          <div className='row'>
            <Button
              ariaLabel='Click to Open'
              onClick={() => this.setState({ showAlert: true, attendees: [{title: 'J $'}] })}
              children='Single Attendee'
              color='primary'
              size='large'
            />
          </div>
          <div className='row'>
            <br />
            <Button
              ariaLabel='Click to Open'
              onClick={() => this.setState({ showAlert: true, attendees: [{title: 'J $'}, {title: 'J G'}] })}
              children='Multiple Attendees'
              color='primary'
              size='large'
            />
          </div>
          <br />
          <AlertMeeting
            attendees={this.state.attendees}
            show={this.state.showAlert}
            onHide={() => this.setState({ showAlert: false })}
            title='Super Important Meeting'
            status='In 5 minutes'
            message='This meeting will blow your mind!'
          />
        </div>
      </section>
    );
  }
}

**/

exports.default = _default;